# zope modules
import unittest
from zope.testing.doctestunit import DocTestSuite
from zope.testing.doctest import DocFileSuite

# jz modules
from test_imagic import TestIFileMagic
from jz.magic.utility import FileMagic


class TestFileMagic(TestIFileMagic):

	def makeTestObject(self):
		return FileMagic


def setUp(test):
	global FileMagic
	test.globs['FileMagic'] = FileMagic


def test_suite():
	return unittest.TestSuite((
		unittest.makeSuite(TestFileMagic),
		DocFileSuite('../readme.txt', setUp=setUp),
		))


if __name__ == '__main__':
	unittest.main(defaultTest='test_suite')


# zope modules
import unittest
from zope.testing.doctestunit import DocTestSuite
from zope.interface.verify import verifyObject

# custom modules
from jz.magic.interfaces import IFileMagic


class TestIFileMagic(unittest.TestCase):
	"""Interface test for magic utility."""

	def makeTestObject(self):
		raise NotImplemented()

	def test_verifyInterfaceImplementation(self):
		self.assert_(verifyObject(IFileMagic, self.makeTestObject()))


def test_suite():
	return unittest.TestSuite((
		))


if __name__ == '__main__':
	unittest.main(defaultTest='test_suite')


# zope modules
from zope.interface import Interface


class IFileMagic(Interface):
	"""File magic utility.

	Use magic bytes to get info about file.
	"""

	def getMimeType(data):
		"""Get mime type of data stream."""

	def getFileExtension(data):
		"""Get file extension based on mime type of data stream."""


# zo pe modules
from zope.interface import implements

# jz modules
from interfaces import IFileMagic

# external modules
import magic


class FileMagic(object):
	"""File magic utility.

	Identify files by their magic code (first few characters in file contents).
	"""

	implements(IFileMagic)

	magicdb = None

	def __init__(self):
		self.magicdb = magic.open(magic.MAGIC_MIME)
		self.magicdb.load()

	def getMimeType(self, data):
		mimetype = self.magicdb.buffer(data)
		return mimetype

	def getFileExtension(self, data):
		mimetype = self.getMimeType(data)
		return mimetype.split("/")[1].split(".")[-1]


FileMagic = FileMagic()